## Replication Materials

###################################################################################################
###################################################################################################

# Enter location of files here
  setwd("...")

# Libraries Needed
  library(ggplot2)
  library(reshape2)
  library(zoo)
  library(Matching)
  library(ebal)
  #devtools::install_github("conjugateprior/austin")  # installs the austin package for wordscores
  library(austin)
  library(tm)


# Functions needed
  
  # Plot ggplot objects in a grid
  multiplot <- function(..., plotlist = NULL, file, cols = 1, layout = NULL) {
    require(grid)
    
    # Make a list from the ... arguments and plotlist
    plots <- c(list(...), plotlist)
    
    numPlots = length(plots)
    
    # If layout is NULL, then use 'cols' to determine layout
    if (is.null(layout)) {
      # Make the panel
      # ncol: Number of columns of plots
      # nrow: Number of rows needed, calculated from # of cols
      layout <- matrix(seq(1, cols * ceiling(numPlots/cols)), 
                       ncol = cols, nrow = ceiling(numPlots/cols))
    }
    
    if (numPlots == 1) {
      print(plots[[1]])
      
    } else {
      # Set up the page
      grid.newpage()
      pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
      
      # Make each plot, in the correct location
      for (i in 1:numPlots) {
        # Get the i, j matrix positions of the regions that contain this subplot
        matchidx <- as.data.frame(which(layout ==  i, arr.ind = TRUE))
        
        print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row, 
                                        layout.pos.col = matchidx$col))
      }
    }
  }
  
  # 95% confidence intervals
  Upper <- function(a){
    se <- sd(a)/sqrt(length(a))
    Upper <- mean(a) + 1.96*se
    return(Upper)
  }
  
  Lower <- function(a){
    se <- sd(a)/sqrt(length(a))
    Lower <- mean(a) - 1.96*se
    return(Lower)
  }
  
###################################################################################################
###################################################################################################
  
#### PART 1: CREATE WORDSCORE ESTIMATES FOR LABOUR MPS ####

# 1. Prep Corpus and term-document matrix
  
# Load all documents being estimated by inserting file location below
  directory <- ".../MP Files"
  
# Create corpus
  textcorpus <- Corpus(DirSource(directory),readerControl = list(reader=readPlain))
  
# Remove white spaces, make lower case
  textcorpus <- tm_map(textcorpus, stripWhitespace)
  textcorpus <- tm_map(textcorpus,content_transformer(tolower))
  
# Remove stopwords 
  textcorpus <- tm_map(textcorpus, removeWords, c("a", "also", "am", "an", "and", "are", "as", "at", "be",
                                                  "because", "but", "by", "go", "going", "gone", "he", "her",
                                                  "hers", "herself", "him", "himself", "his", "i", "if", "in",
                                                  "is", "it", "itself", "may", "me", "my", "myself", "of",
                                                  "on", "or", "our", "ours", "ourselves", "out", "perhaps",
                                                  "so", "that", "the", "their", "theirs", "them", "then", 
                                                  "therefore", "these", "they", "this", "those", "though", 
                                                  "thus", "to", "us", "was", "we", "went", "when", "where",
                                                  "whether", "which", "while", "who", "whom", "with", 
                                                  "would", "you", "your", "yours", "yourself", "yourselves",
                                                  "for", "its", "has", "had", "have", "s", "now", "do", 
                                                  "does", "there", "yes", "no", "than", "can", "could", "re",
                                                  "she","will","per","non","how","from","been","being",
                                                  "irranca","hon","ion","yts","benchers","tories","finsbury",
                                                  "some","such","said","say","tory","ms short","theour","ask",
                                                  "any","all","point","not"))
  
# Due to an issue with new version of tm package, need to extract the document names at this point (removing numbers also removes the document names)
  wordmat <- TermDocumentMatrix(textcorpus)
  col.names <- colnames(wordmat)
  
# Remove numbers
  textcorpus <- tm_map(textcorpus,removeNumbers)
  
# Create term document matrix, name the columns
  wordmat1 <- TermDocumentMatrix(textcorpus)
  colnames(wordmat1) <- col.names
  
# Remove rare words
  wordmat1 <- removeSparseTerms(wordmat, 0.97)  #remove words occurring in only some docs [if =0.99, in only one doc; shd consider 0.985]
  
# Final term document matrix
  wordmat1 <- as.matrix(wordmat1)
  dim(wordmat1)  
  
########################
  
#2. Wordscores
  
# Set References
  ref <- c(which(colnames(wordmat1)=="ref_left.txt"),which(colnames(wordmat1)=="ref_right.txt")) # reference texts
  vir <- 1:length(colnames(wordmat1)) # all texts
  vir <- vir[-ref]  # virgin texts only
  
# Convert to the format needed for austin, a word frequency matrix
  wordmatws <- as.wfm(wordmat1)
  
# Score the reference documents
  r <- getdocs(wordmatws, ref)
  ws <- classic.wordscores(r, scores=c(-5,5))
  thescores <- coef(ws)
  
# Wordscore results for all virgin documents
  v <- getdocs(wordmatws, vir)
  results <- as.data.frame(predict(ws, newdata=v))
  
# Sort out names and period dummy
  names<-c(rownames(results))
  results$names <- names
  
  results$firstperiod <- rep(0,length(results$names))
  for(i in 1: length(results$names)){
    if( length(grep("8794",results$names[i])) > 0 ){
      results$firstperiod[i] <- 1
    }
  }
  
  results$namesOld <- results$names
  for(i in 1:length(results$names)){
    results$names[i] <- gsub("_"," ",results$names[i])
    results$names[i] <- gsub(" 8794","",results$names[i])
    results$names[i] <- gsub(".txt","",results$names[i])
  }
  
  
# standard errors and confidence intervals
  colnames(results)[2] <- "stderror"
  results$lower <- results$Score - (results$stderror*1.96)
  results$upper <- results$Score + (results$stderror*1.96)
  
# final dataset
  results <- subset(results, select = c(6,8,1,9,10,2,7))
  save(results,file="C:/Users/Tom/Dropbox (Personal)/Dissertation/write-ups/Chapter 4/Replication Materials/positions_cps.Rda")
  
  
###############################################################################################################################
###############################################################################################################################

  
#### PART 2: FIGURES AND TABLES IN THE PAPER ####
  
### 1. FIGURE 1, PATTERNS IN REPRESENTATION ###
load("mps_occupations_cps.Rda")
  
  # Plot
  pdf(file="fig1_mpsallsince87_cps.pdf",width=8.5,height=4.8)
  par(mfrow=c(1,2),mar=c(6,4,4,2))
  plot(mps_occupations_cps[,1],ylim=c(0,35),typ="o",
       lwd=1.8,cex=1.2,pch=15,yaxt="n",xaxt="n",col="darkred",xlab="",
       ylab="Percent of Labour MPs",cex.lab=1,
       main="Careerist and Working-Class MPs",cex.main=0.85,cex.lab=0.8)
  lines(mps_occupations_cps[,4],ylim=c(0,100),type="o",
        lwd=1.8,cex=1.2,pch=17,col="dodgerblue3")
  
  axis(1,labels=c("1987-92","1992-97","1997-01","2001-05","2005-10","2010-15"),at=c(1:6),
       cex.axis=0.7)
  axis(2,las=1,cex.axis=0.9)

  plot(mps_occupations_cps[,2],ylim=c(0,35),typ="o",
       lwd=1.5,pch=16,yaxt="n",xaxt="n",col="darkmagenta",xlab="",
       ylab="Percent of Labour MPs",
       main="Other Types of MP",cex.main=0.85,cex.lab=0.8)
  lines(mps_occupations_cps[,3],ylim=c(0,100),typ="o",
        lwd=1.5,pch=13,col="forestgreen")
  lines(mps_occupations_cps[,5],ylim=c(0,100),typ="o",
        lwd=1.5,pch=3,col="goldenrod3")
  
  axis(1,labels=c("1987-92","1992-97","1997-01","2001-05","2005-10","2010-15"),at=c(1:6),cex.axis=0.7)
  axis(2,las=1,cex.axis=0.9)
  
  par(fig = c(0, 1, 0, 1), oma = c(0, 0, 0, 0), mar = c(0, 0, 0, 0), new = TRUE)
  plot(0, 0, type = "n", bty = "n", xaxt = "n", yaxt = "n")
  legend(-0.6,-0.85, c("Working Class", "Careerist",
                       "Professional","Public & Voluntary Sectors","Private Sector"), 
         xpd = TRUE, inset = c(0,0), lwd=c(rep(1.5,5)),pch=c(15,17,16,13,3),
         col=c("darkred","dodgerblue3","darkmagenta","forestgreen","goldenrod3"),
         ncol=3,cex = 0.7)
  
  dev.off()
  
  
###################################################################################################

### Figure 2, densities of wordscores positions ###

  y <- load("positions_cps.Rda")
  p <- get(y)
  rm(y)
 
# Tidy up the wordscores estimates
  p$names[p$names=="Nicholas Brown"] <-"Nick Brown"
  p$names[p$names=="Alan WilliamsSwansea"] <-"Alan Williams"
  p$names[p$names=="Thomas Graham"] <-"Tommy Graham"
  p$names[p$names=="Thomas McAvoy"] <-"Tommy McAvoy"
  p1 <- p[p$firstperiod==1,]
  p2 <- p[p$firstperiod==0,]
  
  p <- p[order(p$Score),]
  p1 <- p1[order(p1$Score),]
  p2 <- p2[order(p2$Score),]
  

# Create melted dataset for plotting
  p1_score <- c(p1$Score, rep(NA,length(p2[,1]) - length(p1[,1])))
  both_p <- as.data.frame(cbind(p1_score,p2$Score))
  colnames(both_p)[2] <- "p2_score"

  bothpm <- melt(both_p)
  bothpm <- bothpm[-(124:201),]
  colnames(bothpm)[1] <- "Period"
  bothpm$Period <- as.character(bothpm$Period)
  bothpm$Period[bothpm$Period=="p2_score"] <- "1994-2007"
  bothpm$Period[bothpm$Period=="p1_score"] <- "1987-1994"
  
# Plot
  densities <- (ggplot(bothpm, aes(x=value, colour=Period)) +
                  geom_line(stat="density",size=1.05) +
                  xlim(-2,2)  +
                  geom_hline(aes(yintercept=0),size=0.001) +
                  xlab("Estimated Wordscores Position") +
                  theme(axis.text.x = element_text(size = 10,colour="black")) +
                  theme(axis.text.y = element_text(size = 10,colour="black")) +
                  theme(axis.title=element_text(size=11)))
  
  pdf(file="fig2_densities_cps.pdf",height=5,width=6)
  densities
  dev.off()
  
  
###################################################################################################

### Figure 3, Estimated Relationships ###
  
# Full dataset of MPs' positions and characteristics 
  load("mpsconstits_cps.Rda")
  
# Estimates
  reg1wcs <- summary(lm(position ~ wclass, data=mpsconstits))
  reg1cs <- summary(lm(position ~ careerist, data=mpsconstits))

# Dataset for plotting
  ests <- c(reg1cs$coef[2], reg1wcs$coef[2])
  se <- c(reg1cs$coef[4],reg1wcs$coef[4])
  names <- c("Careerist","Working-Class")
  relationships <- as.data.frame(cbind(names,ests,se))
  relationships$names <- as.character(relationships$names)
  relationships$se <- as.numeric(as.character(relationships$se))
  relationships$ests <- as.numeric(as.character(relationships$ests))
  relationships$lower <- relationships$ests - (relationships$se*1.96)
  relationships$upper <- relationships$ests + (relationships$se*1.96)
  
# Figure
  relationships$index <- c(1:2)
  est.relationships <- (ggplot(relationships, aes(y=index, x=ests)) + 
                        geom_errorbarh(aes(xmin=lower, xmax=upper), height=.1, col="darkred") +
                        geom_point(aes(y=index, x=ests), size=2, col="darkred", shape=21, fill="darkred") +
                        geom_vline(aes(xintercept=0)) +
                        scale_y_discrete(name="",limits=c(relationships$names))+
                        xlab("Estimated Difference") +
                        #geom_hline(aes(yintercept=2.5),lty=3) +
                        #ggtitle("(b) Impact of Being Careerist \n") +
                        scale_x_continuous(limits = c(-0.7,0.7)) +
                        theme(plot.title = element_text(size=11,colour="black",face="bold")) +
                        theme(axis.text.y = element_text(size = 9,colour="black",hjust=0)) +
                        theme(axis.text.x = element_text(size = 9,colour="black")) +
                        theme(axis.title=element_text(size=10)))
  
  pdf(file ="fig3_relationships_cps.pdf",width=4.5,height=2.2)
  est.relationships
  dev.off()

  
###################################################################################################
  
### Table 1, Regression Results ###

# (i) Working-Class 
  
# Just demographic controls
  reg_col1 <- summary(lm(position ~ wclass + careerist + dob + sex + uni + black, data=mpsconstits))
# Plus constituency benefit use
  reg_col2 <- summary(lm(position ~ wclass + careerist + bens + dob +sex + uni + black, data=mpsconstits))
# Plus constituency majority
  reg_col3 <- summary(lm(position ~ wclass + careerist + bens + maj + dob +sex + uni + black, data=mpsconstits))

  
###################################################################################################
  
### Figure 4, Matching ###
  
  # Working-Class, demographics only 
  matching_est1 <- Match(Y=mpsconstits$position, Tr=mpsconstits$wclass, 
                         X=cbind(mpsconstits$dob,mpsconstits$sex,mpsconstits$uni,mpsconstits$black),
                         BiasAdjust=TRUE,estimand="ATT",M=1)
  
  # Working-Class, demographics + benefit use
  matching_est2 <- Match(Y=mpsconstits$position, Tr=mpsconstits$wclass,
                         X=cbind(mpsconstits$dob,mpsconstits$sex,mpsconstits$uni,
                                 mpsconstits$black,mpsconstits$bens),
                         BiasAdjust=TRUE,estimand="ATT",M=1)
  
  # Working_Class, demographics + benefit use + size of majority
  matching_est3 <- Match(Y=mpsconstits$position, Tr=mpsconstits$wclass,
                         X=cbind(mpsconstits$dob,mpsconstits$sex,mpsconstits$uni,
                                 mpsconstits$black,mpsconstits$bens,mpsconstits$maj),
                         BiasAdjust=TRUE,estimand="ATT",M=1)

  ## data frame for left panel
  ests <- c(matching_est3$est, matching_est2$est, matching_est1$est)
  se <- c(matching_est3$se, matching_est2$se, matching_est1$se)
  names <- c("All Controls",
             "Demographic Controls, \nConstituency Benefit Use",
             "Demographic Controls")
  
  wclass_pic <- as.data.frame(cbind(names,ests,se))
  wclass_pic$names <- as.character(wclass_pic$names)
  wclass_pic$se <- as.numeric(as.character(wclass_pic$se))
  wclass_pic$ests <- as.numeric(as.character(wclass_pic$ests))
  wclass_pic$lower <- wclass_pic$ests - (wclass_pic$se*1.96)
  wclass_pic$upper <- wclass_pic$ests + (wclass_pic$se*1.96)
  
  ## Left Panel of figure
  wclass_pic$index <- c(1:3)
  wclass.pic <- (ggplot(wclass_pic, aes(y=index, x=ests)) + 
                   geom_errorbarh(aes(xmin=lower, xmax=upper), height=.1, col="darkred") +
                   geom_point(aes(y=index, x=ests), size=2, col="darkred", shape=21, fill="darkred") +
                   geom_vline(aes(xintercept=0)) +
                   scale_y_discrete(name="",limits=c(wclass_pic$names))+
                   xlab("Estimate") +
                   ggtitle("(a) Impact of Being Working Class \n") +
                   scale_x_continuous(limits = c(-0.8,0.2)) +
                   theme(plot.title = element_text(size=9,colour="black",face="bold")) +
                   theme(axis.text.y = element_text(size = 8,colour="black",hjust=0)) +
                   theme(axis.text.x = element_text(size = 8,colour="black")) +
                   theme(axis.title=element_text(size=8)))

  
  
  # Careerist, demographics only 
  matching_est1 <- Match(Y=mpsconstits$position, Tr=mpsconstits$careerist, 
                         X=cbind(mpsconstits$dob,mpsconstits$sex,mpsconstits$uni,mpsconstits$black),
                         BiasAdjust=TRUE,estimand="ATT",M=1)
  # Careerist, demographics + benefit use
  matching_est2 <- Match(Y=mpsconstits$position, Tr=mpsconstits$careerist,
                         X=cbind(mpsconstits$dob,mpsconstits$sex,mpsconstits$uni,
                                 mpsconstits$black,mpsconstits$bens),
                         BiasAdjust=TRUE,estimand="ATT",M=1)
  # Careerist, demographics + benefit use + size of majority
  matching_est3 <- Match(Y=mpsconstits$position, Tr=mpsconstits$careerist,
                         X=cbind(mpsconstits$dob,mpsconstits$sex,mpsconstits$uni,
                                 mpsconstits$black,mpsconstits$bens,mpsconstits$maj),
                         BiasAdjust=TRUE,estimand="ATT",M=1)
  
  
  ## data frame for right panel
  ests <- c(matching_est3$est, matching_est2$est, matching_est1$est)
  se <- c(matching_est3$se, matching_est2$se, matching_est1$se)
  names <- c("All Controls",
             "Demographic Controls, \nConstituency Benefit Use",
             "Demographic Controls")
  
  careerist_pic <- as.data.frame(cbind(names,ests,se))
  careerist_pic$names <- as.character(careerist_pic$names)
  careerist_pic$se <- as.numeric(as.character(careerist_pic$se))
  careerist_pic$ests <- as.numeric(as.character(careerist_pic$ests))
  careerist_pic$lower <- careerist_pic$ests - (careerist_pic$se*1.96)
  careerist_pic$upper <- careerist_pic$ests + (careerist_pic$se*1.96)
  
  ## Right Panel of figure
  careerist_pic$index <- c(1:3)
  careerist.pic <- (ggplot(careerist_pic, aes(y=index, x=ests)) + 
                      geom_errorbarh(aes(xmin=lower, xmax=upper), height=.1, col="darkred") +
                      geom_point(aes(y=index, x=ests), size=2, col="darkred", shape=21, fill="darkred") +
                      geom_vline(aes(xintercept=0)) +
                      scale_y_discrete(name="",limits=c(careerist_pic$names))+
                      xlab("Estimate") +
                      ggtitle("(b) Impact of Being Careerist \n") +
                      scale_x_continuous(limits = c(-0.2,0.8)) +
                      theme(plot.title = element_text(size=9,colour="black",face="bold")) +
                      theme(axis.text.y = element_text(size = 8,colour="black",hjust=0)) +
                      theme(axis.text.x = element_text(size = 8,colour="black")) +
                      theme(axis.title=element_text(size=8)))
  
  
  
  # both w class and careerists together
  pdf(file ="fig4_matching_cps.pdf",width=8,height=3.5)
  multiplot(wclass.pic,careerist.pic,cols=2)
  dev.off()
  
  
###################################################################################################
  
### Figure 5, Deaths and Retirements ###
  
# Create dataset of just the switchers and replacements
  name <-c("Allen McKay","Bob Clay","Dave Nellist","Donald Coleman","Eddie Loyden","Harry Ewing",
           "James Lamond","Ron Leighton","Michael Clapham","Bill Etherington","Jim Cunningham",
           "Peter Hain","Maria Eagle","Michael Connarty","Michael Meacher","Stephen Timms")
  MP <- c(rep("Original",8),rep("Replacement",8))
  mps_switch <- as.data.frame(cbind(name,MP))
  
# names for plotting
  mps_switch$name_use <-c("Allen McKay -> Michael Clapham","Bob Clay -> Bill Etherington",
                          "Dave Nellist -> Jim Cunningham","Donald Coleman -> Peter Hain",
                          "Eddie Loyden -> Maria Eagle","Harry Ewing -> Michael Connarty",
                          "James Lamond -> Michael Meacher","Ron Leighton -> Stephen Timms",
                          "Allen McKay -> Michael Clapham","Bob Clay -> Bill Etherington",
                          "Dave Nellist -> Jim Cunningham","Donald Coleman -> Peter Hain",
                          "Eddie Loyden -> Maria Eagle","Harry Ewing -> Michael Connarty",
                          "James Lamond -> Michael Meacher","Ron Leighton -> Stephen Timms")
  
# Assign positions
  mps_switch$upper = mps_switch$lower = mps_switch$Score <- rep(NA,length(mps_switch$name))
  for(i in c(1:8)){
    mps_switch$Score[i] <- p1$Score[which(p1$names==mps_switch$name[i])]
    mps_switch$lower[i] <- p1$lower[which(p1$names==mps_switch$name[i])]
    mps_switch$upper[i] <- p1$upper[which(p1$names==mps_switch$name[i])]
  }
  
  mps_switch$Score[15] <- p1$Score[which(p1$names==mps_switch$name[15])]
  mps_switch$lower[15] <- p1$lower[which(p1$names==mps_switch$name[15])]
  mps_switch$upper[15] <- p1$upper[which(p1$names==mps_switch$name[15])]
  
  for(i in c(9:14,16)){
    mps_switch$Score[i] <- p2$Score[which(p2$names==mps_switch$name[i])]
    mps_switch$lower[i] <- p2$lower[which(p2$names==mps_switch$name[i])]
    mps_switch$upper[i] <- p2$upper[which(p2$names==mps_switch$name[i])]
  }
  

  mps_switchpic <- (ggplot(data = mps_switch, aes(x = name_use, y = Score, ymin = lower, 
                                               ymax = upper, colour = MP)) +
                   geom_point(position = position_dodge(width = 0),size=1) +
                   geom_errorbar(position = position_dodge(width = 0), width = 0.1) +
                   coord_flip() +
                   scale_x_discrete(name="") +  
                   scale_colour_manual(values = c("darkgreen", "darkorange")) +
                   theme(axis.text.x = element_text(size = 8,colour="black",hjust=0))+
                   theme(axis.text.y = element_text(size = 9,colour="black")) +
                   ylab("Estimated Wordscores Position") +
                   theme(axis.title=element_text(size=9)) +
                   theme(legend.text = element_text(size = 9)) +
                   theme(legend.title = element_text(size=10)) +
                   theme(axis.ticks = element_line(size = 0.2)))
  
  pdf(file="fig5_mpsswitch_cps.pdf",width=6,height=3.5)
  mps_switchpic
  dev.off()
  
###################################################################################################
  
### Figure 6, Comparing working-class and careerist MPS with similar benefit use ###
  set.seed(1000)
  
  
  mpsconstits.trc <- mpsconstits[mpsconstits$careerist==1|mpsconstits$wclass==1,]

# This takes a few mins to run
  positions.car = names.car = positions.wc = 
    names.wc = matrix(NA,nrow=length(mpsconstits$wclass[mpsconstits$wclass==1]),ncol=1000)
  pvals = diff = c()
  for(i in 1:1000){
    mpsconstits.trc <- mpsconstits.trc[sample(nrow(mpsconstits.trc)),]
    matching_est3 <- Match(Y=mpsconstits.trc$position, Tr=mpsconstits.trc$careerist,
                           X=cbind(mpsconstits.trc$bens),estimand="ATT",M=1,replace=F,ties=F)
    m2  <- MatchBalance(careerist~ bens, match.out=matching_est3, ks=T, data=mpsconstits.trc)
    bt <- baltest.collect(m2,c("bens"),after=T)
    
    pvals[i] <- bt[6]
    diff[i] <- bt[1] - bt[2]
    
    positions.car[,i] <- mpsconstits.trc$position[matching_est3$index.treated]
    positions.wc[,i] <- mpsconstits.trc$position[matching_est3$index.control]
    names.car[,i] <- mpsconstits.trc$name[matching_est3$index.treated]
    names.wc[,i] <- mpsconstits.trc$name[matching_est3$index.control]
    
  }
  
# select which one to use: highest pval
  index <- which(pvals==max(pvals))
  diff[index]
  
  
# matched dataset for careerists
  matched.constits.car <- as.data.frame(cbind(positions.car[,index],names.car[,index]))
  colnames(matched.constits.car)[1] <- "position"
  colnames(matched.constits.car)[2] <- "name"
  
  matched.constits.car$upper = matched.constits.car$lower <- c()
  for(i in 1:length(matched.constits.car[,1])){
    
    matched.constits.car$lower[i] <- p2$lower[which(p2$names==matched.constits.car$name[i])]
    matched.constits.car$upper[i] <- p2$upper[which(p2$names==matched.constits.car$name[i])]
    
  }
  
  matched.constits.car$group <- c(rep("Careerist",length(matched.constits.car[,1])))
  matched.constits.car$name_pic <- matched.constits.car$name
  matched.constits.car$position <- as.double(as.character(matched.constits.car$position))
  
  matched.constits.car$bens <- c()
  for(i in 1:length(matched.constits.car[,1])){
    
    matched.constits.car$bens[i] <- mpsconstits$bens[which(mpsconstits$name==matched.constits.car$name[i])]
    
  }
  
# matched dataset for the matched controls
  matched.constits.wc <- as.data.frame(cbind(positions.wc[,index],names.wc[,index]))
  colnames(matched.constits.wc)[1] <- "position"
  colnames(matched.constits.wc)[2] <- "name"
  
  matched.constits.wc$upper = matched.constits.wc$lower <- c()
  for(i in 1:length(matched.constits.wc[,1])){
    
    matched.constits.wc$lower[i] <- p2$lower[which(p2$names==matched.constits.wc$name[i])]
    matched.constits.wc$upper[i] <- p2$upper[which(p2$names==matched.constits.wc$name[i])]
    
  }
  
  matched.constits.wc$group <- c(rep("Working-Class Match",length(matched.constits.wc[,1])))
  matched.constits.wc$name_pic <- matched.constits.car$name
  matched.constits.wc$position <- as.double(as.character(matched.constits.wc$position))
  matched.constits.wc$bens <- matched.constits.car$bens
  
  matched.constits.car$oscore <- matched.constits.car$position 
  matched.constits.wc$oscore <- matched.constits.car$position
  
# dataset for figure
  matched.data <- as.data.frame(rbind(matched.constits.car,matched.constits.wc))
  matched.data <- matched.data[order(matched.data$bens),]
  matched.data$name_pic <- as.character(matched.data$name_pic)
  matched.data$name_pic <- factor(matched.data$name_pic, levels=unique(matched.data$name_pic))
  colnames(matched.data)[5] <- "Group"
  
  write.csv(matched.data, file="matcheddata_cps.csv")

# figure  
  pdf(file="fig6_matchedconstits_bens_cps.pdf")
  ggplot(data = matched.data, aes(x = name_pic, y = position, ymin = lower, ymax = upper, colour = Group)) +
    geom_point(position = position_dodge(width = 0),size=1.5) +
    geom_errorbar(position = position_dodge(width = 0), width = 0.1) +
    coord_flip() +
    scale_x_discrete(name="") +  
    scale_colour_manual(values = c("darkgreen", "darkorange")) +
    #geom_hline(aes(yintercept=p1_uq),size=0.4) +
    theme(axis.text.x = element_text(size = 11,colour="black",hjust=0))+
    theme(axis.text.y = element_text(size = 7,colour="black")) +
    theme(axis.title=element_text(size=11))
  dev.off()
  
  
###################################################################################################

### Figure 7: Comparing working-class and careerist MPS with similar majorities ###

  positions.car = names.car = positions.wc = 
    names.wc = matrix(NA,nrow=length(mpsconstits$wclass[mpsconstits$wclass==1]),ncol=1000)
  for(i in 1:1000){
    mpsconstits.trc <- mpsconstits.trc[sample(nrow(mpsconstits.trc)),]
    matching_est3 <- Match(Y=mpsconstits.trc$position, Tr=mpsconstits.trc$careerist,
                           X=cbind(mpsconstits.trc$maj),estimand="ATT",M=1,replace=F,ties=F)
    m2  <- MatchBalance(careerist~ maj, match.out=matching_est3, ks=T, data=mpsconstits.trc)
    bt <- baltest.collect(m2,c("maj"),after=T)
    
    pvals[i] <- bt[6]
    diff[i] <- abs(bt[1] - bt[2])
    
    positions.car[,i] <- mpsconstits.trc$position[matching_est3$index.treated]
    positions.wc[,i] <- mpsconstits.trc$position[matching_est3$index.control]
    names.car[,i] <- mpsconstits.trc$name[matching_est3$index.treated]
    names.wc[,i] <- mpsconstits.trc$name[matching_est3$index.control]
    
  }
  
  index <- which(pvals==max(pvals))
  pvals[index]
  diff[index]
  
  
  # matched dataset for careerists
  matched.constits.car <- as.data.frame(cbind(positions.car[,index],names.car[,index]))
  colnames(matched.constits.car)[1] <- "position"
  colnames(matched.constits.car)[2] <- "name"
  
  matched.constits.car$upper = matched.constits.car$lower <- c()
  for(i in 1:length(matched.constits.car[,1])){
    
    matched.constits.car$lower[i] <- p2$lower[which(p2$names==matched.constits.car$name[i])]
    matched.constits.car$upper[i] <- p2$upper[which(p2$names==matched.constits.car$name[i])]
    
  }
  
  matched.constits.car$group <- c(rep("Careerist",length(matched.constits.car[,1])))
  matched.constits.car$name_pic <- matched.constits.car$name
  matched.constits.car$position <- as.double(as.character(matched.constits.car$position))
  
  matched.constits.car$maj <- c()
  for(i in 1:length(matched.constits.car[,1])){
    
    matched.constits.car$maj[i] <- mpsconstits$maj[which(mpsconstits$name==matched.constits.car$name[i])]
    
  }
  
  # matched dataset for the matched controls
  matched.constits.wc <- as.data.frame(cbind(positions.wc[,index],names.wc[,index]))
  colnames(matched.constits.wc)[1] <- "position"
  colnames(matched.constits.wc)[2] <- "name"
  
  matched.constits.wc$upper = matched.constits.wc$lower <- c()
  for(i in 1:length(matched.constits.wc[,1])){
    
    matched.constits.wc$lower[i] <- p2$lower[which(p2$names==matched.constits.wc$name[i])]
    matched.constits.wc$upper[i] <- p2$upper[which(p2$names==matched.constits.wc$name[i])]
    
  }
  
  for(i in 1:length(matched.constits.wc[,1])){
    
    matched.constits.wc$majwc[i] <- mpsconstits$maj[which(mpsconstits$name==matched.constits.wc$name[i])]
    
  }
  
  matched.constits.wc$group <- c(rep("Working-Class Match",length(matched.constits.wc[,1])))
  matched.constits.wc$name_pic <- matched.constits.car$name
  matched.constits.wc$position <- as.double(as.character(matched.constits.wc$position))
  matched.constits.wc$maj <- matched.constits.car$maj
  matched.constits.car$majwc <- matched.constits.wc$majwc

  
  matched.constits.car$oscore <- matched.constits.car$position 
  matched.constits.wc$oscore <- matched.constits.car$position
  
  # dataset for pic
  matched.data <- as.data.frame(rbind(matched.constits.car,matched.constits.wc))
  matched.data <- matched.data[order(matched.data$maj),]
  matched.data$name_pic <- as.character(matched.data$name_pic)
  matched.data$name_pic <- factor(matched.data$name_pic, levels=unique(matched.data$name_pic))
  colnames(matched.data)[5] <- "Group"
  
  write.csv(matched.data, file="matcheddata_maj.csv")
  
  pdf(file="fig7_matchedconstits_maj_cps.pdf")
  ggplot(data = matched.data, aes(x = name_pic, y = position, ymin = lower, ymax = upper, colour = Group)) +
    geom_point(position = position_dodge(width = 0),size=1.5) +
    geom_errorbar(position = position_dodge(width = 0), width = 0.1) +
    coord_flip() +
    scale_x_discrete(name="") +  
    scale_colour_manual(values = c("darkgreen", "darkorange")) +
    #geom_hline(aes(yintercept=p1_uq),size=0.4) +
    theme(axis.text.x = element_text(size = 11,colour="black",hjust=0))+
    theme(axis.text.y = element_text(size = 7,colour="black")) +
    theme(axis.title=element_text(size=11))
  dev.off()
  
  
  
###################################################################################################
  
### Figure 8: over-time chart for MPs appearing twice ### 
  
# Dataset of subset of MPs appearing in both periods 
  load("overtimechange_cps.Rda")
  
  Means <- c(mean(ptwice_reg$Score_first[which(ptwice_reg$careerist==1 )]),
             mean(ptwice_reg$Score_second[which(ptwice_reg$careerist==1 )]),
             mean(ptwice_reg$Score_first[which(ptwice_reg$wclass==1 )]),
             mean(ptwice_reg$Score_second[which(ptwice_reg$wclass==1 )]))
  
  Uppers <- c(Upper(ptwice_reg$Score_first[which(ptwice_reg$careerist==1 )]),
              Upper(ptwice_reg$Score_second[which(ptwice_reg$careerist==1 )]),
              Upper(ptwice_reg$Score_first[which(ptwice_reg$wclass==1 )]),
              Upper(ptwice_reg$Score_second[which(ptwice_reg$wclass==1 )]))
  
  Lowers <- c(Lower(ptwice_reg$Score_first[which(ptwice_reg$careerist==1 )]),
              Lower(ptwice_reg$Score_second[which(ptwice_reg$careerist==1 )]),
              Lower(ptwice_reg$Score_first[which(ptwice_reg$wclass==1 )]),
              Lower(ptwice_reg$Score_second[which(ptwice_reg$wclass==1 )]))
  
  Period <- rep(c("1987-1994","1994-2007"),2)
  name <- c("b","b","a","a")
  effects <- data.frame(Means,Uppers,Lowers,Period,name)
  
  pdf(file="fig8_overtime_cps.pdf",height=3,width=6.8)
  ggplot(data = effects, aes(x = name, y = Means, ymin = Lowers, ymax = Uppers, colour = Period)) +
    geom_point(position = position_dodge(width = 0),size=2) +
    geom_errorbar(position = position_dodge(width = 0), width = 0.05) +
    coord_flip() +
    scale_x_discrete(name="") +  
    scale_colour_manual(values = c("darkgreen", "darkorange")) +
    geom_hline(aes(yintercept=0),size=0.1) +
    theme(axis.text.x = element_text(size = 11,colour="black",hjust=0))+
    theme(axis.text.y = element_text(size = 11,colour="black")) +
    theme(axis.title=element_text(size=11)) +
    labs(y = "Estimated Position") +
    labs(x = "") +
    scale_x_discrete(labels=c("Working-Class",
                              "Careerist"))
  dev.off() 
  
###################################################################################################
  
### Figure 9: over-time chart for MPs appearing twice ### 

# Load data for 8794
  mps8794 <- load("MPS8794all_CPS.Rda")

  Means <- c(mean(mps8794_all$position[which(mps8794_all$careerist==1)]),
             mean(mpsconstits$position[which(mpsconstits$careerist==1)]),
             mean(mps8794_all$position[which(mps8794_all$finance_bus==1)]),
             mean(mpsconstits$position[which(mpsconstits$finance_bus==1)]),
             mean(mps8794_all$position[which(mps8794_all$prof==1)]),
             mean(mpsconstits$position[which(mpsconstits$prof==1)]),
             mean(mps8794_all$position[which(mps8794_all$public_vol==1)]),
             mean(mpsconstits$position[which(mpsconstits$public_vol==1)]),  
             mean(mps8794_all$position[which(mps8794_all$wclass==1)]),
             mean(mpsconstits$position[which(mpsconstits$wclass==1)]))

  Uppers <- c(Upper(mps8794_all$position[which(mps8794_all$careerist==1)]),
              Upper(mpsconstits$position[which(mpsconstits$careerist==1)]),
              Upper(mps8794_all$position[which(mps8794_all$finance_bus==1)]),
              Upper(mpsconstits$position[which(mpsconstits$finance_bus==1)]),
              Upper(mps8794_all$position[which(mps8794_all$prof==1)]),
              Upper(mpsconstits$position[which(mpsconstits$prof==1)]),
              Upper(mps8794_all$position[which(mps8794_all$public_vol==1)]),
              Upper(mpsconstits$position[which(mpsconstits$public_vol==1)]),  
              Upper(mps8794_all$position[which(mps8794_all$wclass==1)]),
              Upper(mpsconstits$position[which(mpsconstits$wclass==1)]))

  Lowers <- c(Lower(mps8794_all$position[which(mps8794_all$careerist==1)]),
              Lower(mpsconstits$position[which(mpsconstits$careerist==1)]),
              Lower(mps8794_all$position[which(mps8794_all$finance_bus==1)]),
              Lower(mpsconstits$position[which(mpsconstits$finance_bus==1)]),
              Lower(mps8794_all$position[which(mps8794_all$prof==1)]),
              Lower(mpsconstits$position[which(mpsconstits$prof==1)]),
              Lower(mps8794_all$position[which(mps8794_all$public_vol==1)]),
              Lower(mpsconstits$position[which(mpsconstits$public_vol==1)]),  
              Lower(mps8794_all$position[which(mps8794_all$wclass==1)]),
              Lower(mpsconstits$position[which(mpsconstits$wclass==1)]))
  
  Period <- rep(c("1987-1994","1994-2007"),5)
  name <- c("e","e","d","d","c","c","b","b","a","a")
  effects <- data.frame(Means,Uppers,Lowers,Period,name)
  
  pdf(file="fig9_overtimeall_cps.pdf",height=5.5,width=6.8)
  ggplot(data = effects, aes(x = name, y = Means, ymin = Lowers, ymax = Uppers, colour = Period)) +
    geom_point(position = position_dodge(width = 0),size=2) +
    geom_errorbar(position = position_dodge(width = 0), width = 0.1) +
    coord_flip() +
    scale_x_discrete(name="") +  
    scale_colour_manual(values = c("darkgreen", "darkorange")) +
    geom_hline(aes(yintercept=0),size=0.1) +
    theme(axis.text.x = element_text(size = 11,colour="black",hjust=0))+
    theme(axis.text.y = element_text(size = 9,colour="black")) +
    theme(axis.title=element_text(size=11)) +
    labs(y = "Estimated Position") +
    labs(x = "") +
    scale_x_discrete(labels=c("Working-Class",
                              "Public & Voluntary\n Sectors",
                              "Professional",
                              "Private Sector",
                              "Careerist"))
  dev.off() 
  
  
  
  
###################################################################################################
  
### Figure 10: over-time chart for MPs appearing twice ### 
  
  
#plot of all rebellions
  pdf(file="fig10_welfarevotes_cps.pdf",width=7.5,height=5.5)
  par(mfrow=c(1,2))
  barplot(c(0.345,0.2,0.041), ylim=c(0,0.42),xlim=c(0,1.2),col="darkred",
          ylab="Proportion",yaxt="n",
          space=0.4,width=0.3,names.arg=c("Working \nClass","Other","Careerist"),
          cex.names=1,cex.lab=1,cex.main=1,
          main = "All Votes on Welfare, 1997-2001")
  axis(2,las=2,cex.axis=1)
  
#just berry amendment
  a=c("Working \nClass","Other","Careerist")
  b=c("Voted Against","Abstained")
  ginis=matrix(nrow=2,ncol=3)
  dimnames(ginis)=list(b,a)
  ginis[1,]=c(0.327,0.159,0.041)
  ginis[2,]=c(0.132,0.072,0.055)
  
  barplot(ginis,beside=TRUE,col=c("darkred","dodgerblue3"),las=1,ylab="Proportion", 
          main="Berry Amendment, 1999 Welfare \nReform and Pensions Bill",ylim=c(0,0.42),
          cex.names=1,cex.main=1,cex.lab=1,cex.axis=1)
  legend("topright",c("Voted Against","Abstained"),
         fill=c("darkred","dodgerblue3"),cex=1)
  dev.off()
  
  
###################################################################################################
###################################################################################################
  
#### PART 3: FIGURES IN THE SUPPLEMENTARY INFO ####
  

### Figure 1: Positions for Selected MPs, 87-94 ###
  
  # First period: selecting MPs
  p1$index <- c(1:length(p1[,1]))
  
  p1$selection <- ifelse(p1$names=="John Hughes"|p1$names=="Tony Benn"|p1$names=="Eric Illsley"|p1$names=="Dave Nellist"|
                           p1$names=="John McAllion"|p1$names=="Jeremy Corbyn"|p1$names=="Dawn Primarolo"|p1$names=="Clive Soley"|
                           p1$names=="Diane Abbott"|p1$names=="George Robertson"|p1$names=="Gwyneth Dunwoody"|p1$names=="Frank Dobson"|
                           p1$names=="Dennis Skinner"|p1$names=="Tommy Graham"|p1$names=="Joan Ruddock"|p1$names=="Ian McCartney"|
                           p1$names=="David Blunkett"|p1$names=="Stuart Bell"|p1$names=="Ann Clwyd"|p1$names=="Andrew Smith"|
                           p1$names=="John Reid"|p1$names=="Sylvia Heal"|p1$names=="Norman Godman"|p1$names=="Tam Dalyell"|
                           p1$names=="Alun Michael"|p1$names=="Mo Mowlam"|p1$names=="Austin Mitchell"|p1$names=="Jeff Rooker"|
                           p1$names=="Ken Livingstone"|p1$names=="Sam Galbraith"|p1$names=="Harriet Harman"|p1$names=="Robin Cook"|
                           p1$names=="Margaret Beckett"|p1$names=="Rhodri Morgan"|p1$names=="John Smith"|p1$names=="Clare Short"|
                           p1$names=="Graham Allen"|p1$names=="Henry McLeish"|p1$names=="Nick Brown"|p1$names=="Michael Meacher"|
                           p1$names=="Frank Field"|p1$names=="Chris Smith"|p1$names=="Adam Ingram"|p1$names=="Gordon Brown"|
                           p1$names=="Roy Hattersley"| p1$names=="Tony Blair"|p1$names=="Donald Dewar"|p1$names=="Keith Bradley"|
                           p1$names=="Malcolm Wicks"|p1$names=="George Galloway",1,0)
  
  
  # First period figure
  p1_pic <- p1[p1$selection==1,]
  p1_pic$index <- c(1:50)
  
  mps_first <- (ggplot(p1_pic, aes(y=index, x=Score)) + 
                  geom_errorbarh(aes(xmin=lower, xmax=upper), height=.1, col="darkred") +
                  geom_point(aes(y=index, x=Score), size=1.5, col="darkred", shape=21, fill="darkred") +
                  geom_vline(aes(xintercept=0)) +
                  #scale_x_continuous(name="", limits=c(-0.05,0.15)) + 
                  scale_y_discrete(name="",limits=c(p1_pic$names))+
                  xlab("Estimated Wordscores Position") +
                  theme(axis.text.y = element_text(size = 9,colour="black",hjust=0))+
                  theme(axis.text.x = element_text(size = 11,colour="black")) +
                  theme(axis.title=element_text(size=11)))
  
  pdf(file="Supplementary Info/period1_errorbars_cps.pdf")
  mps_first
  dev.off()
  
######################################################
  
### Figure 2: Positions for Selected MPs, 94-07 ###
  
  p2$index <- c(1:length(p2[,1]))
  
  p2$selection <- ifelse(p2$names=="Eric Clarke"|p2$names=="Michael Martin"|p2$names=="Tommy Graham"|p2$names=="Tony Benn"|
                           p2$names=="Glenda Jackson"|p2$names=="John McAllion"|p2$names=="Jeremy Corbyn"|p2$names=="Dennis Skinner"|
                           p2$names=="Ken Livingstone"|p2$names=="Kate Hoey"|p2$names=="Tam Dalyell"|p2$names=="Sam Galbraith"|
                           p2$names=="Nick Raynsford"|p2$names=="John McDonnell"|p2$names=="Donald Dewar"|p2$names=="Gwyneth Dunwoody"|
                           p2$names=="Karen Buck"|p2$names=="Chris Smith"|p2$names=="Adam Ingram"|p2$names=="Frank Field"|
                           p2$names=="Alan Howarth"|p2$names=="Rosie Winterton"|p2$names=="Chris Bryant"|p2$names=="Jacqui Smith"|
                           p2$names=="Patricia Hewitt"|p2$names=="Diane Abbott"|p2$names=="Margaret Beckett"|p2$names=="Stephen Byers"|
                           p2$names=="Malcolm Wicks"|p2$names=="Caroline Flint"|p2$names=="Jon Cruddas"|p2$names=="Paul Boateng"|
                           p2$names=="Peter Hain"|p2$names=="John Reid"|p2$names=="Des Browne"|p2$names=="Jane Kennedy"|
                           p2$names=="Gordon Brown"|p2$names=="Anne McGuire"|p2$names=="Dawn Primarolo"|p2$names=="Douglas Alexander"|
                           p2$names=="Alan Johnson"|p2$names=="Margaret Hodge"| p2$names=="James Purnell"|p2$names=="Harriet Harman"|
                           p2$names=="Ruth Kelly"|p2$names=="David Blunkett"|p2$names=="Alistair Darling"|p2$names=="Jim Murphy"|
                           p2$names=="Andrew Smith"|p2$names=="John Hutton",1,0)
  
  
  p2_pic <- p2[p2$selection==1,]
  p2_pic$index <- c(1:50)
  
  mps_second <- (ggplot(p2_pic, aes(y=index, x=Score)) + 
                   geom_errorbarh(aes(xmin=lower, xmax=upper), height=.1, col="darkred") +
                   geom_point(aes(y=index, x=Score), size=1.5, col="darkred", 
                              shape=21, fill="darkred") +
                   geom_vline(aes(xintercept=0)) +
                   #scale_x_continuous(name="", limits=c(-0.05,0.15)) + 
                   scale_y_discrete(name="",limits=c(p2_pic$names))+
                   xlab("Estimated Wordscores Position") +
                   theme(axis.text.y = element_text(size = 9,colour="black",hjust=0))+
                   theme(axis.text.x = element_text(size = 11,colour="black")) +
                   theme(axis.title=element_text(size=11)))
  
  pdf(file="Supplementary Info/period2_errorbars_cps.pdf")
  mps_second
  dev.off()
  
######################################################  
  
### Figure 3: Change in Positions for Selected MPs ###
  
# Data for the figure
  load("overtimechange_cat1_cps.Rda")
  
  # Plot
  ptwice.fig <- (ggplot(data = ptwice_cat, aes(x = names, y = Score, ymin = lower, 
                                               ymax = upper, colour = period)) +
                   geom_point(position = position_dodge(width = 0),size=1.5) +
                   geom_errorbar(position = position_dodge(width = 0), width = 0.1) +
                   coord_flip() +
                   scale_x_discrete(name="") +  
                   scale_colour_manual(values = c("darkgreen", "darkorange")) +
                   geom_vline(aes(xintercept=17.5),size=0.5) +
                   geom_vline(aes(xintercept=26.5),size=0.5) +
                   theme(axis.text.x = element_text(size =11,colour="black",hjust=0))+
                   theme(axis.text.y = element_text(size = 9,colour="black")) +
                   theme(axis.title=element_text(size=11)))
  
  pdf(file="Supplementary Info/ptwice_cps.pdf")
  ptwice.fig
  dev.off()
  
  
  
#######################################################
  
### Figure 4: Validation Using Groups of MPs ###
  
  # First period, campaign group vs. future ministers
  
  p1$campgroup <- ifelse(p1$names=="Alan Simpson"|p1$names=="Alice Mahon"|p1$names=="Audrey Wise"|p1$names=="Austin Mitchell"|
                           p1$names=="Bill Michie"|p1$names=="Bob Cryer"|p1$names=="Dawn Primarolo"|p1$names=="Dennis Skinner"|
                           p1$names=="Dave Nellist"|p1$names=="Diane Abbott"|p1$names=="Eric Heffer"|p1$names=="Frank Cook"|
                           p1$names=="Harry Barnes"|p1$names=="Jeremy Corbyn"|p1$names=="Jimmy Hood"|p1$names=="Jimmy Wray"|
                           p1$names=="John McAllion"|p1$names=="John Hughes"|p1$names=="Ken Livingstone"|p1$names=="Malcolm Chisholm"|
                           p1$names=="Maria Fyfe"|p1$names=="Mildred Gordon"|p1$names=="Robert Litherland"|p1$names=="Ronnie Campbell"|
                           p1$names=="Tony Banks"|p1$names=="Tony Benn"|p1$names=="Robert Wareing",1,0)
  
  p1$ministers <- ifelse(p1$names=="Adam Ingram"|p1$names=="Alun Michael"|p1$names=="Andrew Smith"|p1$names=="Brian Wilson"|
                           p1$names=="Chris Smith"|p1$names=="Clare Short"|p1$names=="Donald Dewar"|p1$names=="Frank Dobson"|
                           p1$names=="Frank Field"|p1$names=="George Foulkes"|p1$names=="George Howarth"|p1$names=="George Mudie"|
                           p1$names=="George Robertson"|p1$names=="Gordon Brown"|p1$names=="Harriet Harman"|p1$names=="Henry McLeish"|
                           p1$names=="Hilary Armstrong"|p1$names=="Ian McCartney"|p1$names=="Jeff Rooker"|p1$names=="Joan Ruddock"|
                           p1$names=="John Battle"|p1$names=="John Reid"|p1$names=="John Spellar"|p1$names=="Malcolm Wicks"|
                           p1$names=="Margaret Beckett"|p1$names=="Michael Meacher"|p1$names=="Mo Mowlam"|p1$names=="Nick Brown"|
                           p1$names=="Nigel Griffiths"|p1$names=="Robin Cook"|p1$names=="David Blunkett"|p1$names=="Tom Clarke"|
                           p1$names=="Tony Blair"|p1$names=="Alan Howarth",1,0)
  
  pdf(file="Supplementary Info/validations_cps.pdf")
  
  par(mfrow=c(2,3))
  boxplot(p1$Score[p1$campgroup==1],p1$Score[p1$campgroup==0&p1$ministers==0],p1$Score[p1$ministers==1],
          xaxt="n",yaxt="n",ylab="Estimated Score",
          main = "(a) First Period, Campaign Group MPs \n vs. Future Ministers",cex.main=0.85)
  axis(1,tick=F,at=(1:3),labels=c("Campaign \n Group", "Others", "Future \n Ministers"),line=1,cex.axis=0.9)
  axis(2,las=1)
  
  
  # Second period, campaign group vs. actual ministers of soc sec
  
  p2$campgroup <- ifelse(p2$names=="Alan Simpson"|p2$names=="Alice Mahon"|p2$names=="Audrey Wise"|p2$names=="Austin Mitchell"|
                           p2$names=="Bill Michie"|p2$names=="Bill Etherington"|p2$names=="Dennis Skinner"|p2$names=="Diane Abbott"|
                           p2$names=="Frank Cook"|p2$names=="Harry Cohen"|p2$names=="Jeremy Corbyn"|p2$names=="Jimmy Wray"|
                           p2$names=="John Cryer"|p2$names=="John McAllion"|p2$names=="John McDonnell"| p2$names=="Ken Livingstone"|
                           p2$names=="Lynne Jones"|p2$names=="Maria Fyfe"|p2$names=="Michael Clapham"|p2$names=="Ronnie Campbell"|
                           p2$names=="Tony Benn"|p2$names=="David Taylor"|p2$names=="Dennis Canavan",1,0)
  
  p2$ministers <- ifelse(p2$names=="Harriet Harman"|p2$names=="David Blunkett"|p2$names=="Tessa Jowell"|p2$names=="Alistair Darling"|
                           p2$names=="Frank Field"|p2$names=="John Denham"|p2$names=="Stephen Timms"|p2$names=="Jeff Rooker"|
                           p2$names=="Andrew Smith"|p2$names=="Alan Johnson"|p2$names=="John Hutton"|p2$names=="Nick Brown"|
                           p2$names=="Des Browne"|p2$names=="Jane Kennedy"|p2$names=="Margaret Hodge",1,0)
  
  
  boxplot(p2$Score[p2$campgroup==1],p2$Score[p2$campgroup==0&p2$ministers==0],p2$Score[p2$ministers==1],
          yaxt="n",xaxt="n",ylab="Estimated Score",cex.main=0.85,
          main = "(b) Second Period, Campaign Group MPs vs. \n Ministers with Responsibility for Welfare",cex.main=0.82)
  axis(1,tick=F,at=(1:3),labels=c("Campaign \n Group", "Others", "Ministers"),line=1,cex.axis=0.9)
  axis(2,las=1)
  
  
  # Second period, top and bottom 50 from kellerman
  
  p2$kbottom50 <- ifelse(p2$names=="Alice Mahon"|p2$names=="Bill Michie"|p2$names=="Bill Etherington"|p2$names=="Dennis Skinner"|
                           p2$names=="Jeremy Corbyn"|p2$names=="John Cryer"|p2$names=="John McDonnell"|p2$names=="Ken Livingstone"|
                           p2$names=="Lynne Jones"|p2$names=="Maria Fyfe"|p2$names=="Michael Clapham"|p2$names=="Tony Benn"|
                           p2$names=="Dale Campbell-Savours"|p2$names=="Harry Cohen"|p2$names=="Judy Mallaber"|p2$names=="Maria Eagle"|
                           p2$names=="Karen Buck"|p2$names=="Chris Pond"|p2$names=="Andrew Dismore"|p2$names=="Angela Smith"|
                           p2$names=="Gordon Prentice"|p2$names=="Ann Clwyd"|p2$names=="Malcolm Chisholm"|p2$names=="Tony Worthington"|
                           p2$names=="Lynne Jones"|p2$names=="John Cryer"|p2$names=="Phil Hope"|p2$names=="Norman Godman",1,0)
  
  p2$ktop50 <- ifelse(p2$names=="Glenda Jackson"|p2$names=="Sam Galbraith"|p2$names=="Bill Tynan"|p2$names=="Brian Jenkins"|
                        p2$names=="Jean Corston"|p2$names=="Gillian Merron"|p2$names=="Ruth Kelly"|p2$names=="Ken Purchase"|
                        p2$names=="Paul Goggins"|p2$names=="Richard Burden"|p2$names=="Don Touhig"|p2$names=="Denis MacShane"|
                        p2$names=="George Mudie"|p2$names=="Rosemary McKenna"|p2$names=="Harriet Harman"|p2$names=="Mike Gapes"|
                        p2$names=="Douglas Alexander"|p2$names=="Frank Field"|p2$names=="Andrew Bennett"|p2$names=="Des Browne"|
                        p2$names=="Clive Soley"|p2$names=="Ted Rowlands",1,0)
  
  
  boxplot(p2$Score[p2$kbottom50==1],p2$Score[p2$ktop50==1],yaxt="n",xaxt="n",ylab="Estimated Score",
          main = "(c) Second Period, MPs in leftmost 50 and \n rightmost 50 from Kellerman (2012)",cex.main=0.83)
  axis(1,tick=F,at=(1:2),labels=c("Most Left \n 50", "Most Right \n 50"),line=1,cex.axis=0.9)
  axis(2,las=1)
  

  
  # Second period, spirling and quinn, ministers+loyalists vs. leftists and rebels
  
  p2$rebels <- ifelse(p2$names=="Alan Simpson"|p2$names=="Alice Mahon"|p2$names=="Audrey Wise"|p2$names=="Bill Michie"|
                        p2$names=="Bill Etherington"|p2$names=="Dennis Skinner"|p2$names=="Diane Abbott"|p2$names=="Frank Cook"|
                        p2$names=="Harry Cohen"|p2$names=="Jeremy Corbyn"|p2$names=="John Cryer"|p2$names=="John McAllion"|
                        p2$names=="John McDonnell"| p2$names=="Ken Livingstone"|p2$names=="Lynne Jones"|p2$names=="Maria Fyfe"|
                        p2$names=="Michael Clapham"|p2$names=="Ronnie Campbell"|p2$names=="Tony Benn"|p2$names=="Andrew Bennett"|
                        p2$names=="Andrew Bennett"|p2$names=="Roger Berry"|p2$names=="Malcolm Chisholm"|p2$names=="Tom Clarke"|
                        p2$names=="Michael Connarty"|p2$names=="Jim Cousins"|p2$names=="Tam Dalyell"|p2$names=="Ian Davidson"|
                        p2$names=="Paul Flynn"|p2$names=="Frank Field"|p2$names=="Neil Gerrard"|p2$names=="Norman Godman"|
                        p2$names=="Kevin McNamara"|p2$names=="Gordon Prentice"|p2$names=="Ted Rowlands"|p2$names=="David Winnick"|
                        p2$names=="Tony Worthington",1,0)
  
  p2$loyalists <- ifelse(p2$names=="Harriet Harman"|p2$names=="David Blunkett"|p2$names=="Tessa Jowell"|p2$names=="Alistair Darling"|
                           p2$names=="John Denham"|p2$names=="Stephen Timms"|p2$names=="Jeff Rooker"|p2$names=="Andrew Smith"|
                           p2$names=="Alan Johnson"|p2$names=="John Hutton"|p2$names=="Nick Brown"|p2$names=="Des Browne"|
                           p2$names=="Jane Kennedy"|p2$names=="Margaret Hodge"|p2$names=="Adam Ingram"|p2$names=="Alun Michael"|
                           p2$names=="Brian Wilson"|p2$names=="Chris Smith"|p2$names=="Clare Short"|p2$names=="Donald Dewar"|
                           p2$names=="Frank Dobson"|p2$names=="George Foulkes"|p2$names=="George Howarth"|p2$names=="Gordon Brown"|
                           p2$names=="Harriet Harman"|p2$names=="Henry McLeish"|p2$names=="Hilary Armstrong"|p2$names=="Ian McCartney"|
                           p2$names=="Joan Ruddock"|p2$names=="John Battle"|p2$names=="John Reid"|p2$names=="John Spellar"|
                           p2$names=="Malcolm Wicks"|p2$names=="Margaret Beckett"|p2$names=="Michael Meacher"|p2$names=="Alan Howarth"|
                           p2$names=="Dale Campbell-Savours"|p2$names=="Sam Galbraith"|p2$names=="Barry Sheerman"|p2$names=="Patricia Hewitt"|
                           p2$names=="Douglas Alexander"|p2$names=="Hugh Bayley"|p2$names=="Anne Begg"|p2$names=="Clive Betts"|
                           p2$names=="Paul Boateng"|p2$names=="Keith Bradley"|p2$names=="Karen Buck"|p2$names=="Colin Burgon"|
                           p2$names=="Richard Burden"|p2$names=="Stephen Byers"|p2$names=="Roger Casale"|p2$names=="Ben Chapman"|
                           p2$names=="David Clelland"|p2$names=="Vernon Coaker"|p2$names=="Michael Meacher"|p2$names=="Lindsay Hoyle"|
                           p2$names=="Joan Humble"|p2$names=="Glenda Jackson"|p2$names=="Helen Jackson"|p2$names=="Brian Jenkins"|
                           p2$names=="Helen Jones"|p2$names=="Barry Jones"|p2$names=="Sally Keeble"|p2$names=="Ruth Kelly"|
                           p2$names=="Andy King"|p2$names=="Tom Levitt"|p2$names=="Helen Liddell"|p2$names=="David Lock"|
                           p2$names=="David Clelland"|p2$names=="Denis MacShane"|p2$names=="Fiona Mactaggart"|p2$names=="Judy Mallaber"|
                           p2$names=="Stephen McCabe"|p2$names=="Andrew Miller"|p2$names=="John McFall"|p2$names=="Anne McGuire"|
                           p2$names=="Rosemary McKenna"|p2$names=="Rhodri Morgan"|p2$names=="Margaret Moran"|p2$names=="Kali Mountford"|
                           p2$names=="Jim Murphy"|p2$names=="James Plaskitt"|p2$names=="Chris Pond"|p2$names=="Dawn Primarolo"|
                           p2$names=="Ken Purchase"|p2$names=="Nick Raynsford"|p2$names=="Geoffrey Robertson"|p2$names=="Barbara Roche"|
                           p2$names=="Jacqui Smith"|p2$names=="Peter Snape"|p2$names=="Clive Soley"|p2$names=="Gisela Stuart"|
                           p2$names=="Gerry Sutcliffe"|p2$names=="Don Touhig"|p2$names=="George Turner"|p2$names=="Michael Wills"|
                           p2$names=="Rosie Winterton",1,0)
  
  
  boxplot(p2$Score[p2$rebels==1],p2$Score[p2$rebels==0&p2$loyalists==0],p2$Score[p2$loyalists==1],
          names=c("Rebels", "Others", "Loyalists"),yaxt="n",xaxt="n",ylab="Estimated Score",cex.lab=0.9,
          main = "(d) Second Period, 'Rebels' and 'Loyalists' \n from Quinn and Spirling (2010)",cex.main=0.85)
  axis(1,tick=F,at=(1:3),labels=c("Rebels", "Others","Loyalists"),line=1,cex.axis=0.9)
  axis(2,las=1)
  
  
  
  # Second period, vote on changes to lone parent benefit [data from Cowley 2002]
  
  p2$rebels1 <- ifelse(p2$names=="Alan Simpson"|p2$names=="Alice Mahon"|p2$names=="Audrey Wise"|p2$names=="Bill Michie"|
                         p2$names=="Bill Etherington"|p2$names=="Dennis Skinner"|p2$names=="Diane Abbott"|p2$names=="Frank Cook"|
                         p2$names=="Harry Barnes"|p2$names=="Jeremy Corbyn"|p2$names=="John Cryer"|p2$names=="John McAllion"|
                         p2$names=="John McDonnell"| p2$names=="Ken Livingstone"|p2$names=="Lynne Jones"|p2$names=="Maria Fyfe"|
                         p2$names=="Dennis Canavan"|p2$names=="Ronnie Campbell"|p2$names=="Tony Benn"|p2$names=="Ann Clwyd"|
                         p2$names=="Brian Iddon"|p2$names=="Roger Berry"|p2$names=="Malcolm Chisholm"|p2$names=="Norman Godman"|
                         p2$names=="Kevin McNamara"|p2$names=="Gordon Prentice"|p2$names=="David Winnick"|p2$names=="Tony Worthington",1,0)
  
  boxplot(p2$Score[p2$rebels1==1],p2$Score[p2$rebels1==0],
          names=c("Rebels", "Non-Rebels"),yaxt="n",xaxt="n",ylab="Estimated Score",
          main = "(e) Second Period, MPs who Voted against \n Lone Parent Benefit Changes",cex.main=0.85)
  axis(1,tick=F,at=(1:2),labels=c("Rebels", "Non-Rebels"),line=1,cex.axis=0.9)
  axis(2,las=1)
  dev.off()
  
  
#######################################################
  
### Words Data for Tables 1 and 2, Using Quinn et al Methodology ###
  
results <- results[order(results$Score),]
k=35  # no. of documents at each end
  
# column indices of top and bottom k people
  indices_low <- c()
  for(i in 1:k){
    indices_low[i] <- which(colnames(wordmat1)==results$namesOld[i])
  }
  indices_hi <- c()
  for(i in (length(results$names)-k):length(results$names)){
    indices_hi[i-length(results$names)+k] <- which(colnames(wordmat1)==results$namesOld[i])
  }
  
# Create two new data frames containing word counts for top and bottom 50
  wordmatLow <- wordmat1[,indices_low]
  wordmatHi <- wordmat1[,indices_hi]
  
  wsumsHi <- as.data.frame(cbind(rownames(wordmatHi),rowSums(wordmatHi)))
  colnames(wsumsHi) <- c("word","wordsum")
  wsumsLow <- as.data.frame(cbind(rownames(wordmatLow),rowSums(wordmatLow)))
  colnames(wsumsLow) <- c("word","wordsum")
  
# calculate log odds 
  wsumsHi$wordsum <- as.numeric(as.character(wsumsHi$wordsum))
  n <- sum(wsumsHi$wordsum)
  alpha0 <- 0.01*n
  wsumsHi$logodds <- c()
  for(i in 1:length(wsumsHi$word)){
    wsumsHi$logodds[i] <- log( (wsumsHi$wordsum[i] + 0.01) / (n + alpha0 -wsumsHi$wordsum[i] - 0.01) )
  }
  
  wsumsLow$wordsum <- as.numeric(as.character(wsumsLow$wordsum))
  n <- sum(wsumsLow$wordsum)
  alpha0 <- 0.01*n
  wsumsLow$logodds <- c()
  for(i in 1:length(wsumsLow$word)){
    wsumsLow$logodds[i] <- log( (wsumsLow$wordsum[i] + 0.01) / (n + alpha0 -wsumsLow$wordsum[i] - 0.01) )
  }
  
# difference in log odds (monroe et al equation 16)
  wordDiffs <- as.data.frame(wsumsLow$word)
  colnames(wordDiffs)[1] <- "word"
  wordDiffs$oddsDiff <- wsumsHi$logodds - wsumsLow$logodds
  
  
# variance calculation (monroe et al equation 22)
  wsumsHi$varpart <- c()
  for(i in 1:length(wsumsHi$word)){
    wsumsHi$varpart[i] <- 1/(wsumsHi$wordsum[i] + 0.01) 
  }
  
  wsumsLow$varpart <- c()
  for(i in 1:length(wsumsLow$word)){
    wsumsLow$varpart[i] <- 1/(wsumsLow$wordsum[i] + 0.01)
  }
  
  wordDiffs$variance <- wsumsHi$varpart + wsumsLow$varpart
  
# calculate z-scores: monroe equation 22  
  wordDiffs$zscore <- c()
  for(i in 1:length(wordDiffs$word)){
    wordDiffs$zscore[i] <- wordDiffs$oddsDiff[i] / (sqrt(wordDiffs$variance[i]))
  }
  
  
## This is what feeds into the tables ## 
  wordDiffs <- wordDiffs[order(wordDiffs$zscore),]
  
  
  
  